@@ -1,6 +1,7 @@
 { package Catalyst::Action::SOAP::DocumentLiteral;
 
   use base qw/Catalyst::Action::SOAP/;
+  use constant NS_SOAP_ENV => "http://www.w3.org/2003/05/soap-envelope";
 
   sub execute {
       my $self = shift;
@@ -9,7 +10,7 @@
       $self->prepare_soap_xml_post($c);
       unless ($c->stash->{soap}->fault) {
           my $envelope = $c->stash->{soap}->parsed_envelope;
-          my ($body) = $envelope->getElementsByTagName('body',0);
+          my ($body) = $envelope->getElementsByTagNameNS(NS_SOAP_ENV, 'Body');
           $self->NEXT::execute($controller, $c, $body);
       }
   }
